# coding: utf-8

# Use ./launch_tests.sh to launch these tests.

from bs4 import BeautifulSoup

from django_check_seo.checks import site
from django_check_seo.utils.keywords_discovery import meta_keywords

html_content = """
<!doctype html>
<html>
    <head>
        <meta name="description" content="Here is the description of the page.">
        <meta name="keywords" content="description,  title">
    </head>
    <body>
        <h2>Subtitle of the page</h2>
    </body>
</html>
"""


class init:
    def __init__(self):
        self.keywords = []
        self.problems = []
        self.warnings = []
        self.success = []

        self.soup = BeautifulSoup(html_content, features="lxml")
        self.full_url = "https://localhost/fake-url/title-of-the-page/"
        # populate class with data
        self.page_stats = site.Site(self.soup, self.full_url)


def test_h2_importance():
    from django_check_seo.checks_list import check_h2

    assert check_h2.importance() == 1


def test_h2_1_nokw():
    from django_check_seo.checks_list import check_h2

    site = init()

    check_h2.run(site)

    for success in site.success:
        assert success.name == "H2 tags were found"
        assert success.settings == "at least one"
        assert success.found == 1
        assert success.searched_in == ["Subtitle of the page"]
        assert (
            success.description
            == "H2 tags are useful because they are explored by search engines and can help them understand the subject of your page."
        )


def test_h2_2_nokw():
    import copy

    from django_check_seo.checks_list import check_h2

    site = init()
    site.soup.body.append(copy.copy(site.soup.find("h2")))

    check_h2.run(site)

    for success in site.success:
        assert success.name == "H2 tags were found"
        assert success.settings == "at least one"
        assert success.found == 2
        assert success.searched_in == ["Subtitle of the page", "Subtitle of the page"]
        assert (
            success.description
            == "H2 tags are useful because they are explored by search engines and can help them understand the subject of your page."
        )


def test_h2_0_nokw():
    from django_check_seo.checks_list import check_h2

    site = init()
    site.soup.find("h2").decompose()
    check_h2.run(site)

    for warning in site.warnings:
        if warning.name == "No h2 tag":
            assert warning.name == "No h2 tag"
            assert warning.settings == "at least one"
            assert warning.found == "none"
            assert warning.searched_in == []


def test_h2_1_nokw_image():
    from django_check_seo.checks_list import check_h2

    site = init()
    site.soup.find("h2").decompose()
    site.soup.body.append(
        (
            BeautifulSoup(
                "<h2><img src='none' alt='Title of the page' /></h2>", features="lxml"
            )
        )
    )
    check_h2.run(site)

    for success in site.success:
        assert success.name == "H2 tags were found"
        assert success.settings == "at least one"
        assert success.found == 1
        assert success.searched_in == ["Title of the page"]
        assert (
            success.description
            == "H2 tags are useful because they are explored by search engines and can help them understand the subject of your page."
        )


def test_h2_1_kw():
    from django_check_seo.checks_list import check_h2, check_keywords

    site = init()

    meta_keywords(site)
    check_keywords.run(site)
    site.soup.find("h2").string = "Title of the page"

    check_h2.run(site)

    for success in site.success:
        if success.name == "Keyword found in h2 tags":
            assert success.name == "Keyword found in h2 tags"
            assert success.settings == "at least one"
            assert success.found == "title"
            assert success.searched_in == ['<b class="good">title</b> of the page']
            assert (
                success.description
                == "Google uses h2 tags to better understand the subjects of your page."
            )


def test_h2_2_kw():
    import copy

    from django_check_seo.checks_list import check_h2, check_keywords

    site = init()

    meta_keywords(site)
    check_keywords.run(site)
    site.soup.find("h2").string = "Title of the page"
    site.soup.body.append(copy.copy(site.soup.find("h2")))

    check_h2.run(site)

    for success in site.success:
        if success.name == "Keyword found in h2 tags":
            assert success.name == "Keyword found in h2 tags"
            assert success.settings == "at least one"
            assert success.found == "title, title"
            assert success.searched_in == [
                '<b class="good">title</b> of the page',
                '<b class="good">title</b> of the page',
            ]
            assert (
                success.description
                == "Google uses h2 tags to better understand the subjects of your page."
            )


def test_h2_1_kws():
    from django_check_seo.checks_list import check_h2, check_keywords

    site = init()

    meta_keywords(site)
    check_keywords.run(site)
    site.soup.find("h2").string = "Title of the page description"

    check_h2.run(site)

    for success in site.success:
        if success.name == "Keyword found in h2 tags":
            assert success.name == "Keyword found in h2 tags"
            assert success.settings == "at least one"
            assert success.found == "description, title"
            assert success.searched_in == [
                '<b class="good">title</b> of the page <b class="good">description</b>'
            ]


def test_h2_2_kws():
    import copy

    from django_check_seo.checks_list import check_h2, check_keywords

    site = init()

    meta_keywords(site)
    check_keywords.run(site)
    site.soup.body.append(copy.copy(site.soup.find("h2")))
    site.soup.find("h2").string = "Title of the page description"

    check_h2.run(site)

    for success in site.success:
        if success.name == "Keyword found in h2 tags":
            assert success.name == "Keyword found in h2 tags"
            assert success.settings == "at least one"
            assert success.found == "description, title"
            assert success.searched_in == [
                '<b class="good">title</b> of the page <b class="good">description</b>',
                "subtitle of the page",
            ]



# Standard Library
import re

from bs4.element import Comment

# Local application / specific library imports
from ..conf import settings


class Site:
    """Structure containing a good amount of resources from the targeted webpage:
    - the settings
    - the soup (from beautifulsoup)
    - the content (all html except header & menu)
    - the full url (canonical public URL for URL-based checks, even when HTML is from draft preview)
    - the keywords
    - the problems & warnings
    """

    def __init__(self, soup, full_url):
        """Populate some vars.

        Arguments:
            soup {bs4.element} -- beautiful soup content (html)
            full_url {str} -- canonical URL used for SEO checks (e.g. public path, not CMS preview)
        """
        self.settings = settings

        self.soup = soup

        # take all content
        self.content = self.soup.find_all("body")

        # remove comments
        for comment in self.soup.find_all(text=lambda text: isinstance(text, Comment)):
            comment.extract()

        # if we have settings to remove unwanted blocks
        if settings.DJANGO_CHECK_SEO_EXCLUDE_CONTENT != "":
            # iterate through each body (should be only 1)
            for body in self.content:
                # and remove selected blocks
                for node in body.select(settings.DJANGO_CHECK_SEO_EXCLUDE_CONTENT):
                    node.extract()

        # get content without doublewords thx to custom separator ("<h1>Title</h1><br /><p>Content</p>" -> TitleContent)
        self.content_text = ""
        for c in self.content:
            self.content_text += c.get_text(separator=" ")

        # strip multiple carriage return (with optional space) to only one
        self.content_text = re.sub(r"(\n( ?))+", "\n", self.content_text)
        # strip multiples spaces (>3) to only 2 (for title readability)
        self.content_text = re.sub(r"   +", "  ", self.content_text)

        self.full_url = full_url
        self.keywords = []
        self.problems = []
        self.warnings = []
        self.success = []



# -*- coding: utf-8 -*-
"""
Resolve Django CMS edit/preview URLs for SEO checks.

When the "page" parameter is a CMS edit or preview URL (e.g. .../cms/placeholder/object/3/edit/372/),
we can resolve it to the public page URL (get_cms_url_for_check_seo) or to the preview URL
(get_preview_url_for_check_seo) so client.get() fetches the right content.
"""

import re
from urllib.parse import urlparse

# Pattern for CMS placeholder edit or preview URL: .../cms/placeholder/object/<object_id>/[edit|preview]/<placeholder_id>/
_CMS_PLACEHOLDER_EDIT_PREVIEW_PATTERN = re.compile(
    r"cms/placeholder/object/(\d+)/(edit|preview)/(\d+)",
    re.IGNORECASE,
)


def _path_from_param(page_param):
    """Return the path part of page_param (strip query string, ensure path)."""
    if not page_param or not page_param.strip():
        return None
    s = page_param.strip()
    if "?" in s:
        s = s.split("?", 1)[0]
    path = urlparse(s).path if s.startswith("/") or "://" in s else s
    if not path.startswith("/"):
        path = "/" + path
    return path


def _path_and_language_from_path(path):
    """
    Split path into (path_without_language, language) for PageUrl lookup.

    PageUrl stores path without the language prefix and language in a separate field.
    - Translated URL (e.g. /en/blog/) → ("/blog/", "en")
    - Non-translated URL (e.g. /blog/) → ("/blog/", "")

    Uses Django's LANGUAGES to detect if the first segment is a language code.
    """
    if not path or path == "/":
        return "/", ""
    segments = [s for s in path.rstrip("/").split("/") if s]
    if not segments:
        return "/", ""
    try:
        from django.conf import settings

        language_codes = [code for code, _ in getattr(settings, "LANGUAGES", [])]
    except Exception:
        language_codes = []
    if language_codes and segments[0] in language_codes:
        language = segments[0]
        rest = segments[1:]
        path_without_lang = "/" + "/".join(rest) if rest else "/"
        return path_without_lang, language
    return path.rstrip("/") or "/", ""


def get_cms_url_for_check_seo(page_param):
    """
    If page_param is a Django CMS edit or preview URL, return the public page path
    by resolving via PageContent and Page.get_absolute_url(). Otherwise return None.

    Returns:
        str: Public path (e.g. /en/blog/) to use for client.get(), or None to use page_param as-is.
    """
    path = _path_from_param(page_param)
    if path is None:
        return None

    from django_check_seo.conf import settings as dcs_settings

    if not getattr(dcs_settings, "DJANGO_CHECK_SEO_CMS_EDIT_URL_TO_PUBLIC", True):
        return None

    match = _CMS_PLACEHOLDER_EDIT_PREVIEW_PATTERN.search(path)
    if not match:
        return None

    object_id = match.group(3)  # .../object/<content_type_id>/edit|preview/<object_id>/
    try:
        from cms.models import PageContent

        content = (
            PageContent.admin_manager.filter(pk=object_id)
            .select_related("page")
            .first()
        )
        if content and content.page_id:
            page = content.page
            public_path = page.get_absolute_url(language=content.language)
            if public_path:
                return public_path if public_path.startswith("/") else "/" + public_path
    except Exception:
        # ImportError when cms is not installed, or RuntimeError etc. when cms is not configured
        pass
    return None


def get_preview_url_for_check_seo(page_param):
    """
    If page_param is a Django CMS edit or preview URL, return the normalized preview path
    (segment edit or preview forced to "preview"). Otherwise return None.

    Returns:
        str: Preview path (e.g. /en/admin/cms/placeholder/object/3/preview/372/) or None.
    """
    path = _path_from_param(page_param)
    if path is None:
        return None

    match = _CMS_PLACEHOLDER_EDIT_PREVIEW_PATTERN.search(path)
    if not match:
        return None

    # Normalize to "preview" (group 2 is the edit|preview segment)
    preview_path = path[: match.start(2)] + "preview" + path[match.end(2) :]
    if "?" in (page_param or ""):
        query = (page_param or "").split("?", 1)[1]
        if query:
            preview_path += "?" + query
    return preview_path if preview_path.startswith("/") else "/" + preview_path


def get_cms_page_id_language(page_param):
    """
    Return (page_id, language) for the given page param (edit/preview URL or public path).

    - If page_param is a Django CMS edit or preview URL, resolve via PageContent
      (object_id is the second number in .../object/<content_type_id>/edit|preview/<object_id>/).
    - Otherwise treat page_param as a public path and resolve via PageUrl when django CMS
      is available (returns (None, None) if not a CMS page or CMS not installed).

    Returns:
        tuple: (page_id, language) or (None, None).
    """
    path = _path_from_param(page_param)
    if path is None:
        return (None, None)

    match = _CMS_PLACEHOLDER_EDIT_PREVIEW_PATTERN.search(path)
    if not match:
        try:
            from cms.models import PageUrl

            path_without_lang, language = _path_and_language_from_path(path)
            page_url = PageUrl.objects.filter(
                path=path_without_lang, language=language or ""
            ).first()
            if not page_url and path_without_lang == "/":
                page_url = PageUrl.objects.filter(
                    path="", language=language or ""
                ).first()
            if page_url:
                return (page_url.page_id, page_url.language or "")
            return (None, None)
        except Exception:
            return (None, None)

    object_id = match.group(3)  # .../object/<content_type_id>/edit|preview/<object_id>/
    try:
        from cms.models import PageContent

        content = PageContent.admin_manager.get(pk=object_id)
        if content and content.page_id:
            return (content.page_id, content.language or "")
    except Exception:
        pass
    return (None, None)



# Tests for CMS edit/preview URL resolution (no django-cms required for these tests)


from django_check_seo.utils.cms_url_resolution import (
    get_cms_page_id_language,
    get_cms_url_for_check_seo,
    get_preview_url_for_check_seo,
)

# --- get_cms_url_for_check_seo ---


def test_get_cms_url_normal_path_returns_none():
    """Normal path is not rewritten."""
    assert get_cms_url_for_check_seo("/fr/ma-page/") is None
    assert get_cms_url_for_check_seo("/") is None


def test_get_cms_url_edit_pattern_without_cms_returns_none():
    """Edit URL pattern without django-cms installed returns None (no resolution)."""
    url = "/en/admin/cms/placeholder/object/3/edit/372/"
    # Without cms.models.PageContent, resolution fails and returns None
    assert get_cms_url_for_check_seo(url) is None


# --- get_preview_url_for_check_seo ---


def test_get_preview_url_edit_returns_preview_path():
    """Edit URL is normalized to preview path."""
    url = "/en/admin/cms/placeholder/object/3/edit/372/"
    assert (
        get_preview_url_for_check_seo(url)
        == "/en/admin/cms/placeholder/object/3/preview/372/"
    )


def test_get_preview_url_edit_with_query_preserves_query():
    """Edit URL with query string preserves it."""
    url = "/en/admin/cms/placeholder/object/3/edit/372/?live-url=/en/blog/"
    assert (
        get_preview_url_for_check_seo(url)
        == "/en/admin/cms/placeholder/object/3/preview/372/?live-url=/en/blog/"
    )


def test_get_preview_url_already_preview_unchanged():
    """Preview URL is returned unchanged (already preview)."""
    url = "/en/admin/cms/placeholder/object/3/preview/372/"
    assert (
        get_preview_url_for_check_seo(url)
        == "/en/admin/cms/placeholder/object/3/preview/372/"
    )


def test_get_preview_url_normal_path_returns_none():
    """Normal path returns None."""
    assert get_preview_url_for_check_seo("/fr/ma-page/") is None
    assert get_preview_url_for_check_seo("/") is None


def test_get_preview_url_with_prefix_language_admin():
    """Path with language/admin prefix is normalized to preview."""
    url = "/en/admin/cms/placeholder/object/42/edit/100/"
    assert (
        get_preview_url_for_check_seo(url)
        == "/en/admin/cms/placeholder/object/42/preview/100/"
    )


# --- get_cms_page_id_language ---


def test_get_cms_page_id_language_edit_url_without_cms_returns_none():
    """Edit URL without django-cms installed returns (None, None)."""
    assert get_cms_page_id_language("/en/admin/cms/placeholder/object/3/edit/372/") == (
        None,
        None,
    )


def test_get_cms_page_id_language_normal_path_returns_none():
    """Public path when CMS not installed or path not in PageUrl returns (None, None)."""
    assert get_cms_page_id_language("/fr/ma-page/") == (None, None)


def test_get_cms_page_id_language_empty_or_root_returns_none():
    """Empty or root path returns (None, None)."""
    assert get_cms_page_id_language("") == (None, None)
    assert get_cms_page_id_language("/") == (None, None)



# Use ./launch_tests.sh to launch these tests.

from bs4 import BeautifulSoup

from django_check_seo.checks import site

html_content = """
<!doctype html>
<html>
    <head>
        <meta name="keywords" content="description,  title">
        <title>Title of the page</title>
    </head>
</html>
"""


class settings:
    def __init__(self):
        self.DJANGO_CHECK_SEO_SETTINGS = {
            "max_link_depth": 4,
            "max_url_length": 70,
        }


class init:
    def __init__(self):
        self.keywords = []
        self.problems = []
        self.warnings = []
        self.success = []
        self.settings = settings()
        self.soup = BeautifulSoup(html_content, features="lxml")
        self.full_url = "https://localhost/fake-url/title-of-the-page/"
        # populate class with data
        self.page_stats = site.Site(self.soup, self.full_url)


def test_url_importance():
    from django_check_seo.checks_list import check_url

    assert check_url.importance() == 1


def test_url_okay():
    from django_check_seo.checks_list import check_url

    site = init()
    check_url.run(site)

    for success in site.success:
        if success.name == "Right amount of level in path":
            assert success.name == "Right amount of level in path"
            assert success.settings == "less than 4"
            assert success.found == 2
            assert success.searched_in == [
                'https://localhost<b><u class="good">/</u></b>fake-url<b><u class="good">/</u></b>title-of-the-page/'
            ]
            assert (
                success.description
                == "Google recommand to organize your content by adding depth in your url, but advises against putting too much depth."
            )

        if success.name == "URL length is great":
            assert success.name == "URL length is great"
            assert success.settings == "less than 70"
            assert success.found == 37
            assert success.searched_in == ["localhost/fake-url/title-of-the-page/"]
            assert (
                success.description
                == "Shorter URLs tend to rank better than long URLs."
            )


def test_url_too_deep():
    from django_check_seo.checks_list import check_url

    site = init()
    site.full_url = "https://localhost/really/too/much/levels/in/path/"
    check_url.run(site)

    for problem in site.problems:
        if problem.name == "Too many levels in path":
            assert problem.name == "Too many levels in path"
            assert problem.settings == "less than 4"
            assert problem.found == 6
            assert problem.searched_in == [
                'https://localhost<b><u>/</u></b>really<b><u>/</u></b>too<b><u>/</u></b>much<b><u>/</u></b>levels<b><u class="problem">/</u></b>in<b><u class="problem">/</u></b>path/'
            ]


def test_url_too_long():
    from django_check_seo.checks_list import check_url

    site = init()
    site.full_url = "https://localhost/this-is-a-veeeeeeery-long-url-which-will-trigger-a-warning-lorem-ipsum/"
    check_url.run(site)

    for warning in site.warnings:
        if warning.name == "URL is too long":
            assert warning.name == "URL is too long"
            assert warning.settings == "less than 70"
            assert warning.found == 81
            assert warning.searched_in == [
                'localhost/this-is-a-veeeeeeery-long-url-which-will-trigger-a-warning-l<b class="problem">orem-ipsum/</b>'
            ]
            assert (
                warning.description
                == "Shorter URLs tend to rank better than long URLs."
            )



# coding: utf-8

# Use ./launch_tests.sh to launch these tests.

from bs4 import BeautifulSoup

from django_check_seo.checks import site
from django_check_seo.utils.keywords_discovery import meta_keywords

html_content = """
<!doctype html>
<html>
    <head>
        <meta name="description" content="Here is the description of the page.">
        <meta name="keywords" content="description,  title">
    </head>
    <body>
    </body>
</html>
"""


class settings:
    def __init__(self):
        self.DJANGO_CHECK_SEO_SETTINGS = {"meta_description_length": [50, 160]}


class init:
    def __init__(self):
        self.keywords = []
        self.problems = []
        self.warnings = []
        self.success = []
        self.settings = settings()
        self.soup = BeautifulSoup(html_content, features="lxml")
        self.full_url = "https://localhost/fake-url/title-of-the-page/"
        # populate class with data
        self.page_stats = site.Site(self.soup, self.full_url)


def test_decription_importance():
    from django_check_seo.checks_list import check_description

    assert check_description.importance() == 1


def test_description_1_nokw():
    from django_check_seo.checks_list import check_description

    site = init()

    check_description.run(site)

    for success in site.success:
        if success.name == "Meta description is present":
            assert success.name == "Meta description is present"
            assert success.settings == "needed"
            assert success.found == "one"
            assert success.searched_in == ["Here is the description of the page."]
            assert (
                success.description
                == "The meta description tag can be displayed in search results if it has the right length, and can influence users. Knowing that Google classifies sites according to user behaviour, it is important to have a relevant description."
            )
        elif success.name == "Only one meta description tag":
            assert success.name == "Only one meta description tag"
            assert success.settings == "only one"
            assert success.found == "one"
            assert success.searched_in == ["Here is the description of the page."]
            assert (
                success.description
                == "Although some people write one meta description by targeted keyword, this is still an uncommon practice that is not yet recognized by all search engines."
            )


def test_description_1_nokw_too_short_1():
    from django_check_seo.checks_list import check_description

    site = init()

    site.soup.select('meta[name="description"]')[0]["content"] = "a"
    check_description.run(site)

    for problem in site.problems:
        if problem.name == "Meta description is too short":
            assert problem.name == "Meta description is too short"
            assert problem.settings == "between 50 and 160 chars "
            assert problem.found == "1 char"
            assert problem.searched_in == ["a"]


def test_description_1_nokw_too_short_49():
    from django_check_seo.checks_list import check_description

    site = init()

    site.soup.select('meta[name="description"]')[0]["content"] = (
        "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
    )
    check_description.run(site)

    for problem in site.problems:
        if problem.name == "Meta description is too short":
            assert problem.name == "Meta description is too short"
            assert problem.settings == "between 50 and 160 chars "
            assert problem.found == "49 chars"
            assert problem.searched_in == [
                "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
            ]


def test_description_1_nokw_too_long_160():
    from django_check_seo.checks_list import check_description

    site = init()

    site.soup.select('meta[name="description"]')[0]["content"] = (
        "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
    )
    check_description.run(site)

    for problem in site.problems:
        if problem.name == "Meta description is present":
            assert problem.settings == "between 50 and 160 chars "
            assert problem.found == "160 chars"
            assert problem.searched_in == [
                "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
            ]


def test_description_1_nokw_too_long_161():
    from django_check_seo.checks_list import check_description

    site = init()

    site.soup.select('meta[name="description"]')[0]["content"] = (
        "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaab"
    )
    check_description.run(site)

    for problem in site.problems:
        if problem.name == "Meta description is present":
            assert problem.settings == "between 50 and 160 chars "
            assert problem.found == "161 chars"
            assert problem.searched_in == [
                "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaab"
            ]


def test_description_1_kw():
    from django_check_seo.checks_list import check_description, check_keywords

    site = init()

    site.soup.select('meta[name="description"]')[0]["content"] = (
        "Here is the description of the page."
    )

    meta_keywords(site)
    check_keywords.run(site)
    check_description.run(site)

    for success in site.success:
        if success.name == "Keywords were found in meta description":
            assert success.settings == "at least one"
            assert success.found == "description"
            assert success.searched_in == [
                'here is the <b class="good">description</b> of the page.'
            ]


def test_description_1_kws():
    from django_check_seo.checks_list import check_description, check_keywords

    site = init()

    site.soup.select('meta[name="description"]')[0]["content"] = (
        "Here is the description of the page without title."
    )

    meta_keywords(site)
    check_keywords.run(site)
    check_description.run(site)

    for success in site.success:
        if success.name == "Keywords were found in meta description":
            assert success.settings == "at least one"
            assert success.found == "description, title"
            assert success.searched_in == [
                'here is the <b class="good">description</b> of the page without <b class="good">title</b>.'
            ]


def test_description_1_length():
    from django_check_seo.checks_list import check_description

    site = init()

    site.soup.select('meta[name="description"]')[0]["content"] = (
        "Here is the description of the page without title."
    )
    check_description.run(site)

    for success in site.success:
        if success.name == "Meta description length is correct":
            assert success.name == "Meta description length is correct"
            assert success.settings == "between 50 and 160 chars "
            assert success.found == "50"
            assert success.searched_in == [
                "Here is the description of the page without title."
            ]
            assert (
                success.description
                == "The meta description tag can be displayed in search results if it has the right length, and can influence users. Knowing that Google classifies sites according to user behaviour, it is important to have a relevant description."
            )


def test_description_2():
    import copy

    from django_check_seo.checks_list import check_description

    site = init()

    site.soup.body.append(copy.copy(site.soup.select('meta[name="description"]')[0]))
    check_description.run(site)

    for warning in site.warnings:
        if warning.name == "Too much meta description tags":
            assert warning.name == "Too much meta description tags"
            assert warning.settings == "only one"
            assert warning.found == 2
            assert warning.searched_in == [
                "Here is the description of the page.",
                "Here is the description of the page.",
            ]
            assert (
                warning.description
                == "Although some people write one meta description by targeted keyword, this is still an uncommon practice that is not yet recognized by all search engines."
            )


def test_description_0():
    from django_check_seo.checks_list import check_description

    site = init()

    site.soup.select('meta[name="description"]')[0].decompose()
    check_description.run(site)

    for problem in site.problems:
        if problem.name == "No meta description":
            assert problem.name == "No meta description"
            assert problem.settings == "needed"
            assert problem.found == "none"
            assert problem.searched_in == []
            assert (
                problem.description
                == "The meta description tag can be displayed in search results if it has the right length, and can influence users. Knowing that Google classifies sites according to user behaviour, it is important to have a relevant description."
            )



# Use ./launch_tests.sh to launch these tests.

import re

from bs4 import BeautifulSoup

from django_check_seo.checks import site
from django_check_seo.utils.keywords_discovery import meta_keywords

html_content = """
<!doctype html>
<html>
    <head>
        <meta name="keywords" content="description,  title">
        <title>Title of the page</title>
    </head>
    <body><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi pharetra metus ut tellus interdum consectetur. In vehicula orci vel fermentum pretium. Vestibulum ante ipsum primis in faucibus orci title luctus et ultrices posuere cubilia Curae; Cras consequat nunc arcu, ut tristique nulla molestie vel. Morbi vitae diam nibh. Proin ex nutella.</p></body>
</html>
"""


class settings:
    def __init__(self):
        self.DJANGO_CHECK_SEO_SETTINGS = {
            "keywords_in_first_words": 50,
        }


class init:
    def __init__(self):
        self.keywords = []
        self.problems = []
        self.warnings = []
        self.success = []
        self.settings = settings()
        self.soup = BeautifulSoup(html_content, features="lxml")

        self.content_text = get_content_text(self.soup.find_all("body"))

        self.full_url = "https://localhost/fake-url/title-of-the-page/"
        # populate class with data
        self.page_stats = site.Site(self.soup, self.full_url)


def get_content_text(soup):
    content_text = ""
    for c in soup:
        content_text += c.get_text(separator=" ")

    # strip multiple carriage return (with optional space) to only one
    content_text = re.sub(r"(\n( ?))+", "\n", content_text)
    # strip multiples spaces (>3) to only 2 (for title readability)
    content_text = re.sub(r"   +", "  ", content_text)
    return content_text


def test_url_importance():
    from django_check_seo.checks_list import keyword_present_first_paragraph

    assert keyword_present_first_paragraph.importance() == 1


def test_keyword_present_first_paragraph_kw():
    from django_check_seo.checks_list import (
        check_keywords,
        keyword_present_first_paragraph,
    )

    site = init()
    meta_keywords(site)
    check_keywords.run(site)
    keyword_present_first_paragraph.run(site)

    for success in site.success:
        if success.name == "Keywords found in first paragraph":
            assert success.name == "Keywords found in first paragraph"
            assert success.settings == "before 50 words"
            assert success.found == "title"
            assert success.searched_in == [
                'lorem ipsum dolor sit amet, consectetur adipiscing elit. morbi pharetra metus ut tellus interdum consectetur. in vehicula orci vel fermentum pretium. vestibulum ante ipsum primis in faucibus orci <b class="good">title</b> luctus et ultrices posuere cubilia curae; cras consequat nunc arcu, ut tristique nulla molestie vel. morbi vitae diam nibh. proin ex'
            ]
            assert (
                success.description
                == "The reader will be relieved to find one of his keywords in the first paragraph of your page, and the same logic applies to Google, which will consider the content more relevant."
            )


def test_keyword_present_first_paragraph_nokw():
    from django_check_seo.checks_list import (
        check_keywords,
        keyword_present_first_paragraph,
    )

    site = init()
    site.soup.find("p").string = "There is no keyword inside first 50 words."
    site.content_text = get_content_text(site.soup.find_all("body"))

    meta_keywords(site)
    check_keywords.run(site)
    keyword_present_first_paragraph.run(site)

    for problem in site.problems:
        if problem.name == "No keyword in first paragraph":
            assert problem.name == "No keyword in first paragraph"
            assert problem.settings == "before 50 words"
            assert problem.found == "none"
            assert problem.searched_in == ["there is no keyword inside first 50 words."]


def test_keyword_present_first_paragraph_kws():
    from django_check_seo.checks_list import (
        check_keywords,
        keyword_present_first_paragraph,
    )

    site = init()
    site.soup.find(
        "p"
    ).string = "There are two kw inside the first paragraph: title and description."
    site.content_text = get_content_text(site.soup.find_all("body"))

    meta_keywords(site)
    check_keywords.run(site)
    keyword_present_first_paragraph.run(site)

    for success in site.success:
        if success.name == "Keywords found in first paragraph":
            assert success.name == "Keywords found in first paragraph"
            assert success.settings == "before 50 words"
            assert success.found == "description, title"
            assert success.searched_in == [
                'there are two kw inside the first paragraph: <b class="good">title</b> and <b class="good">description</b>.'
            ]
            assert (
                success.description
                == "The reader will be relieved to find one of his keywords in the first paragraph of your page, and the same logic applies to Google, which will consider the content more relevant."
            )



# Tests for get_cms_page_id_language_for_path (without django-cms)


from django_check_seo.utils.keywords_discovery import get_cms_page_id_language_for_path


def test_get_cms_page_id_language_without_cms_returns_none():
    """When django CMS is not installed, path is not resolved to (id, language)."""
    assert get_cms_page_id_language_for_path("/fr/ma-page/") == (None, None)
    assert get_cms_page_id_language_for_path("/") == (None, None)


def test_get_cms_page_id_language_normalizes_path():
    """Path is normalized with leading slash."""
    assert get_cms_page_id_language_for_path("fr/ma-page/") == (None, None)



# Use ./launch_tests.sh to launch these tests.

import re

from bs4 import BeautifulSoup

from django_check_seo.checks import site

html_content = """
<!doctype html>
<html>
    <head>
        <meta name="keywords" content="description,  title">
        <title>Title of the page</title>
    </head>
    <body><p>Content of the page.</p></body>
</html>
"""


class settings:
    def __init__(self):
        self.DJANGO_CHECK_SEO_SETTINGS = {
            "content_words_number": [300, 600],
        }


class init:
    def __init__(self):
        self.keywords = []
        self.problems = []
        self.warnings = []
        self.success = []
        self.settings = settings()
        self.soup = BeautifulSoup(html_content, features="lxml")

        self.content_text = get_content_text(self.soup.find_all("body"))

        self.full_url = "https://localhost/fake-url/title-of-the-page/"
        # populate class with data
        self.page_stats = site.Site(self.soup, self.full_url)


def get_content_text(soup):
    content_text = ""
    for c in soup:
        content_text += c.get_text(separator=" ")

    # strip multiple carriage return (with optional space) to only one
    content_text = re.sub(r"(\n( ?))+", "\n", content_text)
    # strip multiples spaces (>3) to only 2 (for title readability)
    content_text = re.sub(r"   +", "  ", content_text)
    return content_text


def test_url_importance():
    from django_check_seo.checks_list import content_words_number

    assert content_words_number.importance() == 1


def test_content_words_number_short():
    from django_check_seo.checks_list import content_words_number

    site = init()
    content_words_number.run(site)

    for problem in site.problems:
        if problem.name == "Content is too short":
            assert problem.name == "Content is too short"
            assert problem.settings == "at least 300 words, more than 600 if possible"
            assert problem.found == 4
            assert problem.searched_in == ["Content of the page."]
            assert (
                problem.description
                == "Longer articles tend to be better ranked, but will require better writing skills than shorter articles."
            )


def test_content_words_number_short2():
    from django_check_seo.checks_list import content_words_number

    site = init()
    site.soup.find(
        "p"
    ).string = "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc vel purus mollis eros imperdiet elementum et sit amet orci. Quisque eget posuere ipsum. Vestibulum in tellus in quam congue maximus. Nam cursus, urna a luctus luctus, eros erat accumsan dolor, et porttitor eros quam ut odio. Quisque vel tortor id metus dignissim ullamcorper sit amet ac nunc. Donec laoreet ipsum nulla, sed scelerisque arcu mattis ac. Quisque diam augue, condimentum nec risus nec, rutrum dignissim felis. Nullam interdum tincidunt mauris, eu euismod ligula rutrum vitae. In accumsan, nisi sit amet commodo ornare, risus est dictum nulla, eu egestas quam dui eget felis. In quis imperdiet lectus. Maecenas sit amet quam eu felis maximus venenatis nec non nunc. Nunc nec viverra quam. Quisque sollicitudin ante ex, ut placerat sapien commodo eget. Etiam vel tempor nulla, vitae venenatis risus. Phasellus a euismod ligula. Suspendisse laoreet lacus eget arcu tempor sollicitudin. Sed maximus, diam et interdum commodo, nisi quam varius odio, et dapibus sem ante quis leo. Praesent gravida viverra augue, molestie bibendum mauris sagittis et. Sed sem quam, congue vitae suscipit non, imperdiet at justo. Nullam nunc lacus, dapibus ac felis nec, faucibus ultrices dui. Etiam est sem, ornare vel ipsum non, tincidunt facilisis augue. Vivamus dolor eros, blandit eget feugiat sit amet, mattis in lorem. Pellentesque in luctus mi. Sed varius, felis sed venenatis porta, ipsum dui molestie nulla, in dapibus lacus ligula sed ipsum. Vivamus vitae est est. Vivamus porttitor dui et nisl faucibus pulvinar. Proin ac neque ornare, commodo erat id, maximus sem. Morbi quis nibh rhoncus, sollicitudin turpis sed, ornare erat. Etiam cursus augue a ante dapibus, id dictum nulla sagittis. Fusce volutpat dui sed vehicula ornare. Vivamus et ipsum dapibus, posuere lectus sed, laoreet enim. Duis molestie, nunc at egestas scelerisque, mi dolor vehicula augue, sed pretium lectus odio et lorem. Sed aliquam tortor nec fringilla fermentum. Nulla suscipit nibh ac lacus ornare tempus. Duis at pellentesque urna."

    site.content_text = get_content_text(site.soup.find_all("body"))

    content_words_number.run(site)

    for warning in site.warnings:
        if warning.name == "Content is too short":
            assert warning.name == "Content is too short"
            assert warning.settings == "at least 300 words, more than 600 if possible"
            assert warning.found == 321
            assert warning.searched_in == [
                "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc vel purus mollis eros imperdiet elementum et sit amet orci. Quisque eget posuere ipsum. Vestibulum in tellus in quam congue maximus. Nam cursus, urna a luctus luctus, eros erat accumsan dolor, et porttitor eros quam ut odio. Quisque vel tortor id metus dignissim ullamcorper sit amet ac nunc. Donec laoreet ipsum nulla, sed scelerisque arcu mattis ac. Quisque diam augue, condimentum nec risus nec, rutrum dignissim felis. Nullam interdum tincidunt mauris, eu euismod ligula rutrum vitae. In accumsan, nisi sit amet commodo ornare, risus est dictum nulla, eu egestas quam dui eget felis. In quis imperdiet lectus. Maecenas sit amet quam eu felis maximus venenatis nec non nunc. Nunc nec viverra quam. Quisque sollicitudin ante ex, ut placerat sapien commodo eget. Etiam vel tempor nulla, vitae venenatis risus. Phasellus a euismod ligula. Suspendisse laoreet lacus eget arcu tempor sollicitudin. Sed maximus, diam et interdum commodo, nisi quam varius odio, et dapibus sem ante quis leo. Praesent gravida viverra augue, molestie bibendum mauris sagittis et. Sed sem quam, congue vitae suscipit non, imperdiet at justo. Nullam nunc lacus, dapibus ac felis nec, faucibus ultrices dui. Etiam est sem, ornare vel ipsum non, tincidunt facilisis augue. Vivamus dolor eros, blandit eget feugiat sit amet, mattis in lorem. Pellentesque in luctus mi. Sed varius, felis sed venenatis porta, ipsum dui molestie nulla, in dapibus lacus ligula sed ipsum. Vivamus vitae est est. Vivamus porttitor dui et nisl faucibus pulvinar. Proin ac neque ornare, commodo erat id, maximus sem. Morbi quis nibh rhoncus, sollicitudin turpis sed, ornare erat. Etiam cursus augue a ante dapibus, id dictum nulla sagittis. Fusce volutpat dui sed vehicula ornare. Vivamus et ipsum dapibus, posuere lectus sed, laoreet enim. Duis molestie, nunc at egestas scelerisque, mi dolor vehicula augue, sed pretium lectus odio et lorem. Sed aliquam tortor nec fringilla fermentum. Nulla suscipit nibh ac lacus ornare tempus. Duis at pellentesque urna."
            ]
            assert (
                warning.description
                == "Longer articles tend to be better ranked, but will require better writing skills than shorter articles."
            )


def test_content_words_number_okay():
    from django_check_seo.checks_list import content_words_number

    site = init()
    site.soup.find(
        "p"
    ).string = "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin eget mollis risus, at tincidunt ipsum. Sed viverra nulla sapien, non lacinia risus rhoncus ut. Proin vitae ante vestibulum, egestas quam eu, rutrum sem. Mauris in commodo eros. Fusce vitae finibus mi, a auctor nulla. Cras eu arcu a lacus congue consectetur vel vel orci. Morbi tempor risus vestibulum molestie tempor. Donec vitae ultricies dolor, non maximus massa. Pellentesque sit amet tincidunt ipsum, id condimentum nulla. Nulla commodo magna ut finibus efficitur. Ut mattis diam metus, vel tristique mi pulvinar et. Pellentesque fermentum ut mauris sit amet fermentum. Phasellus ac nunc vel dolor maximus mattis. Nunc et mauris sit amet nunc malesuada gravida vel feugiat turpis. Pellentesque interdum mattis mauris quis tempor. Pellentesque vehicula mauris et tempus tincidunt. In hac habitasse platea dictumst. Nulla orci dolor, eleifend et varius quis, fringilla sed ipsum. Aliquam erat volutpat. Donec accumsan nec justo at congue. Fusce a erat a massa pulvinar posuere eu quis enim. Nam maximus nunc sem, eget lacinia magna volutpat sit amet. Nam ipsum velit, imperdiet eu lacus ac, faucibus finibus ante. In hac habitasse platea dictumst. Vestibulum in turpis sit amet nibh placerat maximus. Aenean libero erat, tincidunt interdum gravida in, facilisis sit amet magna. Suspendisse pulvinar tincidunt est, id finibus mi volutpat non. Maecenas at condimentum elit, vitae congue metus. Nulla sit amet ullamcorper orci, eget dapibus urna. Pellentesque vitae nisi nec mauris lobortis pharetra non mollis nisi. Morbi ut pretium quam. Nunc dapibus dui dui, nec dignissim mauris aliquam vitae. Nam interdum dolor lacus, vel viverra ligula sollicitudin sit amet. Etiam nec leo eu diam vestibulum varius a vel tellus. Pellentesque nec viverra metus, eu fringilla odio. Valar morghulis luctus varius leo, a congue tortor facilisis ac. Nullam consequat enim ac nulla convallis imperdiet. Sed porttitor auctor pellentesque. Ut pellentesque lectus vel ultricies consequat. Cras nec enim eros. Etiam fringilla quis ante vel dapibus. Morbi tempor arcu magna, id tincidunt ante finibus id. Curabitur ac mauris rhoncus, coucou maman, condimentum lectus. Phasellus ultricies rutrum nisi. Aliquam lacinia ex id malesuada interdum. Curabitur lorem justo, iaculis vel sagittis eget, ornare in erat. Maecenas suscipit dictum volutpat. Pellentesque metus lectus, laoreet ut lacus id, dignissim molestie dui. Ut enim tortor, iaculis vitae pulvinar id, sagittis nec nibh. Curabitur sit amet faucibus velit. Curabitur sed suscipit nunc. Praesent nisi ligula, tempor id aliquam sit amet, fringilla aliquam metus. Nam bibendum blandit turpis quis feugiat. Aenean iaculis ipsum ac felis rutrum, et mollis lacus interdum. Mauris auctor nunc vitae mi pulvinar consectetur. Praesent porttitor diam nec ex placerat ornare. Etiam eu dapibus lacus. Morbi nec nibh varius, lacinia nulla vel, placerat leo. AD il a des lunettes. Duis nisi ligula, finibus non leo dapibus, euismod accumsan neque. Pellentesque tincidunt fringilla dolor eu eleifend. Nam vestibulum nulla vel risus ultrices posuere ut ornare est. Aliquam erat volutpat. Duis arcu enim, posuere in nunc eu, consequat porttitor nisl. Morbi interdum tincidunt erat, ac efficitur risus. Suspendisse potenti. Nulla at convallis massa. Aenean eros dui, facilisis mattis diam a, dignissim ultricies nunc. Vestibulum quis elit id mauris elementum auctor. Sed nec nunc molestie, lacinia erat id, elementum nisi. Maecenas eget porttitor urna. Nunc facilisis iaculis diam a imperdiet. Aenean imperdiet aliquam varius. Nullam nec tempor urna. Donec sapien urna, fermentum et faucibus vehicula, dignissim in dui. Vivamus scelerisque, risus at dictum hendrerit, magna arcu pellentesque orci, et faucibus augue urna sit amet erat. Nullam ullamcorper massa orci, nec feugiat enim scelerisque et. Morbi mollis dui at orci dictum tincidunt. Vivamus ut suscipit mauris. Donec iaculis, nibh id consectetur elementum, ligula nibh maximus tellus, ac efficitur est augue eu ligula. Pellentesque id."

    site.content_text = get_content_text(site.soup.find_all("body"))

    content_words_number.run(site)

    for success in site.success:
        if success.name == "Content length is right":
            assert success.name == "Content length is right"
            assert success.settings == "at least 300 words, more than 600 if possible"
            assert success.found == 606
            assert success.searched_in == [
                'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin eget mollis risus, at tincidunt ipsum. Sed viverra nulla sapien, non lacinia risus rhoncus ut. Proin vitae ante vestibulum, egestas quam eu, rutrum sem. Mauris in commodo eros. Fusce vitae finibus mi, a auctor nulla. Cras eu arcu a lacus congue consectetur vel vel orci. Morbi tempor risus vestibulum molestie tempor. Donec vitae ultricies dolor, non maximus massa. Pellentesque sit amet tincidunt ipsum, id condimentum nulla. Nulla commodo magna ut finibus efficitur. Ut mattis diam metus, vel tristique mi pulvinar et. Pellentesque fermentum ut mauris sit amet fermentum. Phasellus ac nunc vel dolor maximus mattis. Nunc et mauris sit amet nunc malesuada gravida vel feugiat turpis. Pellentesque interdum mattis mauris quis tempor. Pellentesque vehicula mauris et tempus tincidunt. In hac habitasse platea dictumst. Nulla orci dolor, eleifend et varius quis, fringilla sed ipsum. Aliquam erat volutpat. Donec accumsan nec justo at congue. Fusce a erat a massa pulvinar posuere eu quis enim. Nam maximus nunc sem, eget lacinia magna volutpat sit amet. Nam ipsum velit, imperdiet eu lacus ac, faucibus finibus ante. In hac habitasse platea dictumst. Vestibulum in turpis sit amet nibh placerat maximus. Aenean libero erat, tincidunt interdum gravida in, facilisis sit amet magna. Suspendisse pulvinar tincidunt est, id finibus mi volutpat non. Maecenas at condimentum elit, vitae congue metus. Nulla sit amet ullamcorper orci, eget dapibus urna. Pellentesque vitae nisi nec mauris lobortis pharetra non mollis nisi. Morbi ut pretium quam. Nunc dapibus dui dui, nec dignissim mauris aliquam vitae. Nam interdum dolor lacus, vel viverra ligula sollicitudin sit amet. Etiam nec leo eu diam vestibulum varius a vel tellus. Pellentesque nec viverra metus, eu fringilla odio. Valar morghulis luctus varius leo, a congue tortor facilisis ac. Nullam consequat enim ac nulla convallis imperdiet. Sed porttitor auctor pellentesque. Ut pellentesque lectus vel ultricies consequat. Cras nec enim eros. Etiam fringilla quis ante vel dapibus. Morbi tempor arcu magna, id tincidunt ante finibus id. Curabitur ac mauris rhoncus, coucou maman, condimentum lectus. Phasellus ultricies rutrum nisi. Aliquam lacinia ex id malesuada interdum. Curabitur lorem justo, iaculis vel sagittis eget, ornare in erat. Maecenas suscipit dictum volutpat. Pellentesque metus lectus, laoreet ut lacus id, dignissim molestie dui. Ut enim tortor, iaculis vitae pulvinar id, sagittis nec nibh. Curabitur sit amet faucibus velit. Curabitur sed suscipit nunc. Praesent nisi ligula, tempor id aliquam sit amet, fringilla aliquam metus. Nam bibendum blandit turpis quis feugiat. Aenean iaculis ipsum ac felis rutrum, et mollis lacus interdum. Mauris auctor nunc vitae mi pulvinar consectetur. Praesent porttitor diam nec ex placerat ornare. Etiam eu dapibus lacus. Morbi nec nibh varius, lacinia nulla vel, placerat leo. AD il a des lunettes. Duis nisi ligula, finibus non leo dapibus, euismod accumsan neque. Pellentesque tincidunt fringilla dolor eu eleifend. Nam vestibulum nulla vel risus ultrices posuere ut ornare est. Aliquam erat volutpat. Duis arcu enim, posuere in nunc eu, consequat porttitor nisl. Morbi interdum tincidunt erat, ac efficitur risus. Suspendisse potenti. Nulla at convallis massa. Aenean eros dui, facilisis mattis diam a, dignissim ultricies nunc. Vestibulum quis elit id mauris elementum auctor. Sed nec nunc molestie, lacinia erat id, elementum nisi. Maecenas eget porttitor urna. Nunc facilisis iaculis diam a imperdiet. Aenean imperdiet aliquam varius. Nullam nec tempor urna. Donec sapien urna, fermentum et faucibus vehicula, dignissim in dui. Vivamus scelerisque, risus at dictum hendrerit, magna arcu pellentesque orci, et faucibus augue urna sit amet erat. Nullam ullamcorper massa orci, nec feugiat enim scelerisque et. Morbi mollis dui at orci dictum tincidunt. Vivamus ut suscipit mauris. Donec iaculis, nibh id consectetur elementum, ligula nibh maximus tellus, ac efficitur<span class="good">est augue eu ligula. Pellentesque id.</span>'
            ]
            assert (
                success.description
                == "Longer articles tend to be better ranked, but will require better writing skills than shorter articles."
            )



# Third party
from django.conf import settings

# define basic SEO settings, see
DJANGO_CHECK_SEO_SETTINGS = {
    "content_words_number": [300, 600],
    "internal_links": 1,
    "external_links": 1,
    "meta_title_length": [30, 60],
    "meta_description_length": [50, 160],
    "keywords_in_first_words": 50,
    "max_link_depth": 4,
    "max_url_length": 70,
}
# update settings redefined in projectname/settings.py
DJANGO_CHECK_SEO_SETTINGS.update(getattr(settings, "DJANGO_CHECK_SEO_SETTINGS", {}))

# define css selector to search content into (used for retrieving main content of the page)
DJANGO_CHECK_SEO_SEARCH_IN = {
    "type": "exclude",
    "selectors": ["header", ".cover-section", "#footer"],
}

#
DJANGO_CHECK_SEO_EXCLUDE_CONTENT = getattr(
    settings, "DJANGO_CHECK_SEO_EXCLUDE_CONTENT", ""
)

# Keywords discovery: import path to a function (site) -> None that sets site.keywords.
# Built-in: django_check_seo.utils.keywords_discovery.meta_keywords (from meta tag),
#          django_check_seo.utils.keywords_discovery.model_keywords (from Page/Keyword by path),
#          django_check_seo.utils.keywords_discovery.django_cms_model_keywords (by cms_page_id+language, fallback path).
DJANGO_CHECK_SEO_KEYWORDS_DISCOVERY_METHOD = getattr(
    settings,
    "DJANGO_CHECK_SEO_KEYWORDS_DISCOVERY_METHOD",
    "django_check_seo.utils.keywords_discovery.meta_keywords",
)

# When True and discovery is model_keywords or django_cms_model_keywords, show editable keywords form.
DJANGO_CHECK_SEO_KEYWORDS_EDITABLE = getattr(
    settings, "DJANGO_CHECK_SEO_KEYWORDS_EDITABLE", False
)

# When True, resolve Django CMS edit/preview URLs to the public page URL for SEO checks (default True).
# When the "page" param is a CMS edit or preview URL, it is resolved via PageContent/Page models.
DJANGO_CHECK_SEO_CMS_EDIT_URL_TO_PUBLIC = getattr(
    settings, "DJANGO_CHECK_SEO_CMS_EDIT_URL_TO_PUBLIC", True
)
